@@ -52,22 +52,23 @@ type QueueType int32
 // Queue types used in queue table
 // Use positive numbers for queue type
 // Negative numbers are reserved for DLQ
+
 const (
 	NamespaceReplicationQueueType QueueType = iota + 1
 )
 
 // Create Workflow Execution Mode
 const (
-	// Fail if current record exists
+	// CreateWorkflowModeBrandNew fail if current record exists
 	// Only applicable for CreateWorkflowExecution
 	CreateWorkflowModeBrandNew CreateWorkflowMode = iota
-	// Update current record only if workflow is closed
+	// CreateWorkflowModeWorkflowIDReuse update current record only if workflow is closed
 	// Only applicable for CreateWorkflowExecution
 	CreateWorkflowModeWorkflowIDReuse
-	// Update current record only if workflow is open
+	// CreateWorkflowModeContinueAsNew update current record only if workflow is open
 	// Only applicable for UpdateWorkflowExecution
 	CreateWorkflowModeContinueAsNew
-	// Do not update current record since workflow to
+	// CreateWorkflowModeZombie do not update current record since workflow is in zombie state
 	// applicable for CreateWorkflowExecution, UpdateWorkflowExecution
 	CreateWorkflowModeZombie
 )
@@ -77,10 +78,10 @@ type UpdateWorkflowMode int
 
 // Update Workflow Execution Mode
 const (
-	// Update workflow, including current record
+	// UpdateWorkflowModeUpdateCurrent update workflow, including current record
 	// NOTE: update on current record is a condition update
 	UpdateWorkflowModeUpdateCurrent UpdateWorkflowMode = iota
-	// Update workflow, without current record
+	// UpdateWorkflowModeBypassCurrent update workflow, without current record
 	// NOTE: current record CANNOT point to the workflow to be updated
 	UpdateWorkflowModeBypassCurrent
 )
@@ -90,10 +91,10 @@ type ConflictResolveWorkflowMode int
 
 // Conflict Resolve Workflow Mode
 const (
-	// Conflict resolve workflow, including current record
+	// ConflictResolveWorkflowModeUpdateCurrent conflict resolve workflow, including current record
 	// NOTE: update on current record is a condition update
 	ConflictResolveWorkflowModeUpdateCurrent ConflictResolveWorkflowMode = iota
-	// Conflict resolve workflow, without current record
+	// ConflictResolveWorkflowModeBypassCurrent conflict resolve workflow, without current record
 	// NOTE: current record CANNOT point to the workflow to be updated
 	ConflictResolveWorkflowModeBypassCurrent
 )
@@ -108,9 +109,6 @@ const (
 	// TransferTaskTransferTargetWorkflowID is the the dummy workflow ID for transfer tasks of types
 	// that do not have a target workflow
 	TransferTaskTransferTargetWorkflowID = "20000000-0000-f000-f000-000000000001"
-
-	// indicate invalid workflow state transition
-	invalidStateTransitionMsg = "unable to change workflow state from %v to %v, status %v"
 )
 
 const numItemsInGarbageInfo = 3
@@ -123,7 +121,19 @@ type (
 
 	// CurrentWorkflowConditionFailedError represents a failed conditional update for current workflow record
 	CurrentWorkflowConditionFailedError struct {
-		Msg string
+		Msg              string
+		RequestID        string
+		RunID            string
+		State            enumsspb.WorkflowExecutionState
+		Status           enumspb.WorkflowExecutionStatus
+		LastWriteVersion int64
+	}
+
+	// WorkflowConditionFailedError represents a failed conditional update for workflow record
+	WorkflowConditionFailedError struct {
+		Msg             string
+		NextEventID     int64
+		DBRecordVersion int64
 	}
 
 	// ConditionFailedError represents a failed conditional update for execution record
@@ -142,16 +152,6 @@ type (
 		Msg     string
 	}
 
-	// WorkflowExecutionAlreadyStartedError is returned when creating a new workflow failed.
-	WorkflowExecutionAlreadyStartedError struct {
-		Msg              string
-		StartRequestID   string
-		RunID            string
-		State            enumsspb.WorkflowExecutionState
-		Status           enumspb.WorkflowExecutionStatus
-		LastWriteVersion int64
-	}
-
 	// TimeoutError is returned when a write operation fails due to a timeout
 	TimeoutError struct {
 		Msg string
@@ -199,8 +199,8 @@ type (
 		SetVersion(version int64)
 		GetTaskID() int64
 		SetTaskID(id int64)
-		GetVisibilityTimestamp() time.Time
-		SetVisibilityTimestamp(timestamp time.Time)
+		GetVisibilityTime() time.Time
+		SetVisibilityTime(timestamp time.Time)
 	}
 
 	// TaskQueueKey is the struct used to identity TaskQueues
@@ -409,6 +409,7 @@ type (
 
 	// AddTasksRequest is used to write new tasks
 	AddTasksRequest struct {
+		ShardID int32
 		RangeID int64
 
 		NamespaceID string
@@ -423,6 +424,7 @@ type (
 
 	// CreateWorkflowExecutionRequest is used to write a new workflow execution
 	CreateWorkflowExecutionRequest struct {
+		ShardID int32
 		RangeID int64
 
 		Mode CreateWorkflowMode
@@ -431,14 +433,17 @@ type (
 		PreviousLastWriteVersion int64
 
 		NewWorkflowSnapshot WorkflowSnapshot
+		NewWorkflowEvents   []*WorkflowEvents
 	}
 
 	// CreateWorkflowExecutionResponse is the response to CreateWorkflowExecutionRequest
 	CreateWorkflowExecutionResponse struct {
+		HistorySize int64
 	}
 
 	// GetWorkflowExecutionRequest is used to retrieve the info of a workflow execution
 	GetWorkflowExecutionRequest struct {
+		ShardID     int32
 		NamespaceID string
 		Execution   commonpb.WorkflowExecution
 	}
@@ -452,12 +457,14 @@ type (
 
 	// GetCurrentExecutionRequest is used to retrieve the current RunId for an execution
 	GetCurrentExecutionRequest struct {
+		ShardID     int32
 		NamespaceID string
 		WorkflowID  string
 	}
 
 	// ListConcreteExecutionsRequest is request to ListConcreteExecutions
 	ListConcreteExecutionsRequest struct {
+		ShardID   int32
 		PageSize  int
 		PageToken []byte
 	}
@@ -479,17 +486,20 @@ type (
 
 	// UpdateWorkflowExecutionRequest is used to update a workflow execution
 	UpdateWorkflowExecutionRequest struct {
+		ShardID int32
 		RangeID int64
 
 		Mode UpdateWorkflowMode
 
 		UpdateWorkflowMutation WorkflowMutation
-
-		NewWorkflowSnapshot *WorkflowSnapshot
+		UpdateWorkflowEvents   []*WorkflowEvents
+		NewWorkflowSnapshot    *WorkflowSnapshot
+		NewWorkflowEvents      []*WorkflowEvents
 	}
 
 	// ConflictResolveWorkflowExecutionRequest is used to reset workflow execution state for a single run
 	ConflictResolveWorkflowExecutionRequest struct {
+		ShardID int32
 		RangeID int64
 
 		Mode ConflictResolveWorkflowMode
@@ -594,6 +604,7 @@ type (
 
 	// DeleteWorkflowExecutionRequest is used to delete a workflow execution
 	DeleteWorkflowExecutionRequest struct {
+		ShardID     int32
 		NamespaceID string
 		WorkflowID  string
 		RunID       string
@@ -601,6 +612,7 @@ type (
 
 	// DeleteCurrentWorkflowExecutionRequest is used to delete the current workflow execution
 	DeleteCurrentWorkflowExecutionRequest struct {
+		ShardID     int32
 		NamespaceID string
 		WorkflowID  string
 		RunID       string
@@ -619,6 +631,7 @@ type (
 
 	// GetTransferTasksRequest is used to read tasks from the transfer task queue
 	GetTransferTasksRequest struct {
+		ShardID       int32
 		ReadLevel     int64
 		MaxReadLevel  int64
 		BatchSize     int
@@ -644,6 +657,7 @@ type (
 
 	// GetVisibilityTasksRequest is used to read tasks from the visibility task queue
 	GetVisibilityTasksRequest struct {
+		ShardID       int32
 		ReadLevel     int64
 		MaxReadLevel  int64
 		BatchSize     int
@@ -669,6 +683,7 @@ type (
 
 	// GetReplicationTasksRequest is used to read tasks from the replication task queue
 	GetReplicationTasksRequest struct {
+		ShardID       int32
 		MinTaskID     int64
 		MaxTaskID     int64
 		BatchSize     int
@@ -683,56 +698,66 @@ type (
 
 	// CompleteTransferTaskRequest is used to complete a task in the transfer task queue
 	CompleteTransferTaskRequest struct {
-		TaskID int64
+		ShardID int32
+		TaskID  int64
 	}
 
 	// RangeCompleteTransferTaskRequest is used to complete a range of tasks in the transfer task queue
 	RangeCompleteTransferTaskRequest struct {
+		ShardID              int32
 		ExclusiveBeginTaskID int64
 		InclusiveEndTaskID   int64
 	}
 
 	// CompleteVisibilityTaskRequest is used to complete a task in the visibility task queue
 	CompleteVisibilityTaskRequest struct {
-		TaskID int64
+		ShardID int32
+		TaskID  int64
 	}
 
 	// RangeCompleteVisibilityTaskRequest is used to complete a range of tasks in the visibility task queue
 	RangeCompleteVisibilityTaskRequest struct {
+		ShardID              int32
 		ExclusiveBeginTaskID int64
 		InclusiveEndTaskID   int64
 	}
 
 	// CompleteReplicationTaskRequest is used to complete a task in the replication task queue
 	CompleteReplicationTaskRequest struct {
-		TaskID int64
+		ShardID int32
+		TaskID  int64
 	}
 
 	// RangeCompleteReplicationTaskRequest is used to complete a range of task in the replication task queue
 	RangeCompleteReplicationTaskRequest struct {
+		ShardID            int32
 		InclusiveEndTaskID int64
 	}
 
 	// PutReplicationTaskToDLQRequest is used to put a replication task to dlq
 	PutReplicationTaskToDLQRequest struct {
+		ShardID           int32
 		SourceClusterName string
 		TaskInfo          *persistencespb.ReplicationTaskInfo
 	}
 
 	// GetReplicationTasksFromDLQRequest is used to get replication tasks from dlq
 	GetReplicationTasksFromDLQRequest struct {
+		ShardID           int32
 		SourceClusterName string
 		GetReplicationTasksRequest
 	}
 
 	// DeleteReplicationTaskFromDLQRequest is used to delete replication task from DLQ
 	DeleteReplicationTaskFromDLQRequest struct {
+		ShardID           int32
 		SourceClusterName string
 		TaskID            int64
 	}
 
 	// RangeDeleteReplicationTaskFromDLQRequest is used to delete replication tasks from DLQ
 	RangeDeleteReplicationTaskFromDLQRequest struct {
+		ShardID              int32
 		SourceClusterName    string
 		ExclusiveBeginTaskID int64
 		InclusiveEndTaskID   int64
@@ -743,12 +768,14 @@ type (
 
 	// RangeCompleteTimerTaskRequest is used to complete a range of tasks in the timer task queue
 	RangeCompleteTimerTaskRequest struct {
+		ShardID                 int32
 		InclusiveBeginTimestamp time.Time
 		ExclusiveEndTimestamp   time.Time
 	}
 
 	// CompleteTimerTaskRequest is used to complete a task in the timer task queue
 	CompleteTimerTaskRequest struct {
+		ShardID             int32
 		VisibilityTimestamp time.Time
 		TaskID              int64
 	}
@@ -855,6 +882,7 @@ type (
 	// GetTimerIndexTasksRequest is the request for GetTimerIndexTasks
 	// TODO: replace this with an iterator that can configure min and max index.
 	GetTimerIndexTasksRequest struct {
+		ShardID       int32
 		MinTimestamp  time.Time
 		MaxTimestamp  time.Time
 		BatchSize     int
@@ -971,6 +999,10 @@ type (
 		DeleteChildInfoCount         int
 		DeleteSignalInfoCount        int
 		DeleteRequestCancelInfoCount int
+
+		// History size diff
+		UpdateWorkflowHistorySizeDiff int64
+		NewWorkflowHistorySizeDiff    int64
 	}
 
 	// UpdateWorkflowExecutionResponse is response for UpdateWorkflowExecutionRequest
@@ -1221,7 +1253,6 @@ type (
 	ExecutionManager interface {
 		Closeable
 		GetName() string
-		GetShardID() int32
 
 		CreateWorkflowExecution(request *CreateWorkflowExecutionRequest) (*CreateWorkflowExecutionResponse, error)
 		GetWorkflowExecution(request *GetWorkflowExecutionRequest) (*GetWorkflowExecutionResponse, error)
@@ -1232,24 +1263,29 @@ type (
 		GetCurrentExecution(request *GetCurrentExecutionRequest) (*GetCurrentExecutionResponse, error)
 
 		// Scan operations
+
 		ListConcreteExecutions(request *ListConcreteExecutionsRequest) (*ListConcreteExecutionsResponse, error)
 
 		// Tasks related APIs
+
 		AddTasks(request *AddTasksRequest) error
 
 		// transfer tasks
+
 		GetTransferTask(request *GetTransferTaskRequest) (*GetTransferTaskResponse, error)
 		GetTransferTasks(request *GetTransferTasksRequest) (*GetTransferTasksResponse, error)
 		CompleteTransferTask(request *CompleteTransferTaskRequest) error
 		RangeCompleteTransferTask(request *RangeCompleteTransferTaskRequest) error
 
 		// timer tasks
+
 		GetTimerTask(request *GetTimerTaskRequest) (*GetTimerTaskResponse, error)
 		GetTimerIndexTasks(request *GetTimerIndexTasksRequest) (*GetTimerIndexTasksResponse, error)
 		CompleteTimerTask(request *CompleteTimerTaskRequest) error
 		RangeCompleteTimerTask(request *RangeCompleteTimerTaskRequest) error
 
 		// replication tasks
+
 		GetReplicationTask(request *GetReplicationTaskRequest) (*GetReplicationTaskResponse, error)
 		GetReplicationTasks(request *GetReplicationTasksRequest) (*GetReplicationTasksResponse, error)
 		CompleteReplicationTask(request *CompleteReplicationTaskRequest) error
@@ -1260,45 +1296,11 @@ type (
 		RangeDeleteReplicationTaskFromDLQ(request *RangeDeleteReplicationTaskFromDLQRequest) error
 
 		// visibility tasks
+
 		GetVisibilityTask(request *GetVisibilityTaskRequest) (*GetVisibilityTaskResponse, error)
 		GetVisibilityTasks(request *GetVisibilityTasksRequest) (*GetVisibilityTasksResponse, error)
 		CompleteVisibilityTask(request *CompleteVisibilityTaskRequest) error
 		RangeCompleteVisibilityTask(request *RangeCompleteVisibilityTaskRequest) error
-	}
-
-	// ExecutionManagerFactory creates an instance of ExecutionManager for a given shard
-	ExecutionManagerFactory interface {
-		Closeable
-		NewExecutionManager(shardID int32) (ExecutionManager, error)
-	}
-
-	// TaskManager is used to manage tasks
-	TaskManager interface {
-		Closeable
-		GetName() string
-		LeaseTaskQueue(request *LeaseTaskQueueRequest) (*LeaseTaskQueueResponse, error)
-		UpdateTaskQueue(request *UpdateTaskQueueRequest) (*UpdateTaskQueueResponse, error)
-		ListTaskQueue(request *ListTaskQueueRequest) (*ListTaskQueueResponse, error)
-		DeleteTaskQueue(request *DeleteTaskQueueRequest) error
-		CreateTasks(request *CreateTasksRequest) (*CreateTasksResponse, error)
-		GetTasks(request *GetTasksRequest) (*GetTasksResponse, error)
-		CompleteTask(request *CompleteTaskRequest) error
-		// CompleteTasksLessThan completes tasks less than or equal to the given task id
-		// This API takes a limit parameter which specifies the count of maxRows that
-		// can be deleted. This parameter may be ignored by the underlying storage, but
-		// its mandatory to specify it. On success this method returns the number of rows
-		// actually deleted. If the underlying storage doesn't support "limit", all rows
-		// less than or equal to taskID will be deleted.
-		// On success, this method returns:
-		//  - number of rows actually deleted, if limit is honored
-		//  - UnknownNumRowsDeleted, when all rows below value are deleted
-		CompleteTasksLessThan(request *CompleteTasksLessThanRequest) (int, error)
-	}
-
-	// HistoryManager is used to manager workflow history events
-	HistoryManager interface {
-		Closeable
-		GetName() string
 
 		// The below are history V2 APIs
 		// V2 regards history events growing as a tree, decoupled from workflow concepts
@@ -1326,6 +1328,29 @@ type (
 		GetAllHistoryTreeBranches(request *GetAllHistoryTreeBranchesRequest) (*GetAllHistoryTreeBranchesResponse, error)
 	}
 
+	// TaskManager is used to manage tasks
+	TaskManager interface {
+		Closeable
+		GetName() string
+		LeaseTaskQueue(request *LeaseTaskQueueRequest) (*LeaseTaskQueueResponse, error)
+		UpdateTaskQueue(request *UpdateTaskQueueRequest) (*UpdateTaskQueueResponse, error)
+		ListTaskQueue(request *ListTaskQueueRequest) (*ListTaskQueueResponse, error)
+		DeleteTaskQueue(request *DeleteTaskQueueRequest) error
+		CreateTasks(request *CreateTasksRequest) (*CreateTasksResponse, error)
+		GetTasks(request *GetTasksRequest) (*GetTasksResponse, error)
+		CompleteTask(request *CompleteTaskRequest) error
+		// CompleteTasksLessThan completes tasks less than or equal to the given task id
+		// This API takes a limit parameter which specifies the count of maxRows that
+		// can be deleted. This parameter may be ignored by the underlying storage, but
+		// its mandatory to specify it. On success this method returns the number of rows
+		// actually deleted. If the underlying storage doesn't support "limit", all rows
+		// less than or equal to taskID will be deleted.
+		// On success, this method returns:
+		//  - number of rows actually deleted, if limit is honored
+		//  - UnknownNumRowsDeleted, when all rows below value are deleted
+		CompleteTasksLessThan(request *CompleteTasksLessThanRequest) (int, error)
+	}
+
 	// MetadataManager is used to manage metadata CRUD for namespace entities
 	MetadataManager interface {
 		Closeable
@@ -1360,6 +1385,10 @@ func (e *CurrentWorkflowConditionFailedError) Error() string {
 	return e.Msg
 }
 
+func (e *WorkflowConditionFailedError) Error() string {
+	return e.Msg
+}
+
 func (e *ConditionFailedError) Error() string {
 	return e.Msg
 }
@@ -1372,10 +1401,6 @@ func (e *ShardOwnershipLostError) Error() string {
 	return e.Msg
 }
 
-func (e *WorkflowExecutionAlreadyStartedError) Error() string {
-	return e.Msg
-}
-
 func (e *TimeoutError) Error() string {
 	return e.Msg
 }
@@ -1384,12 +1409,6 @@ func (e *TransactionSizeLimitError) Error() string {
 	return e.Msg
 }
 
-// IsTimeoutError check whether error is TimeoutError
-func IsTimeoutError(err error) bool {
-	_, ok := err.(*TimeoutError)
-	return ok
-}
-
 // GetType returns the type of the activity task
 func (a *ActivityTask) GetType() enumsspb.TaskType {
 	return enumsspb.TASK_TYPE_TRANSFER_ACTIVITY_TASK
@@ -1416,12 +1435,12 @@ func (a *ActivityTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (a *ActivityTask) GetVisibilityTimestamp() time.Time {
+func (a *ActivityTask) GetVisibilityTime() time.Time {
 	return a.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (a *ActivityTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (a *ActivityTask) SetVisibilityTime(timestamp time.Time) {
 	a.VisibilityTimestamp = timestamp
 }
 
@@ -1456,12 +1475,12 @@ func (d *ReplicationTaskInfoWrapper) GetVisibilityTime() *time.Time {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (d *WorkflowTask) GetVisibilityTimestamp() time.Time {
+func (d *WorkflowTask) GetVisibilityTime() time.Time {
 	return d.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (d *WorkflowTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (d *WorkflowTask) SetVisibilityTime(timestamp time.Time) {
 	d.VisibilityTimestamp = timestamp
 }
 
@@ -1491,12 +1510,12 @@ func (a *ResetWorkflowTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (a *ResetWorkflowTask) GetVisibilityTimestamp() time.Time {
+func (a *ResetWorkflowTask) GetVisibilityTime() time.Time {
 	return a.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (a *ResetWorkflowTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (a *ResetWorkflowTask) SetVisibilityTime(timestamp time.Time) {
 	a.VisibilityTimestamp = timestamp
 }
 
@@ -1526,12 +1545,12 @@ func (a *CloseExecutionTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (a *CloseExecutionTask) GetVisibilityTimestamp() time.Time {
+func (a *CloseExecutionTask) GetVisibilityTime() time.Time {
 	return a.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (a *CloseExecutionTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (a *CloseExecutionTask) SetVisibilityTime(timestamp time.Time) {
 	a.VisibilityTimestamp = timestamp
 }
 
@@ -1561,12 +1580,12 @@ func (a *DeleteHistoryEventTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (a *DeleteHistoryEventTask) GetVisibilityTimestamp() time.Time {
+func (a *DeleteHistoryEventTask) GetVisibilityTime() time.Time {
 	return a.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (a *DeleteHistoryEventTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (a *DeleteHistoryEventTask) SetVisibilityTime(timestamp time.Time) {
 	a.VisibilityTimestamp = timestamp
 }
 
@@ -1596,12 +1615,12 @@ func (d *WorkflowTaskTimeoutTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime gets the visibility time stamp
-func (d *WorkflowTaskTimeoutTask) GetVisibilityTimestamp() time.Time {
+func (d *WorkflowTaskTimeoutTask) GetVisibilityTime() time.Time {
 	return d.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp gets the visibility time stamp
-func (d *WorkflowTaskTimeoutTask) SetVisibilityTimestamp(t time.Time) {
+// SetVisibilityTime gets the visibility time stamp
+func (d *WorkflowTaskTimeoutTask) SetVisibilityTime(t time.Time) {
 	d.VisibilityTimestamp = t
 }
 
@@ -1631,12 +1650,12 @@ func (a *ActivityTimeoutTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime gets the visibility time stamp
-func (a *ActivityTimeoutTask) GetVisibilityTimestamp() time.Time {
+func (a *ActivityTimeoutTask) GetVisibilityTime() time.Time {
 	return a.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp gets the visibility time stamp
-func (a *ActivityTimeoutTask) SetVisibilityTimestamp(t time.Time) {
+// SetVisibilityTime gets the visibility time stamp
+func (a *ActivityTimeoutTask) SetVisibilityTime(t time.Time) {
 	a.VisibilityTimestamp = t
 }
 
@@ -1666,12 +1685,12 @@ func (u *UserTimerTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime gets the visibility time stamp
-func (u *UserTimerTask) GetVisibilityTimestamp() time.Time {
+func (u *UserTimerTask) GetVisibilityTime() time.Time {
 	return u.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp gets the visibility time stamp
-func (u *UserTimerTask) SetVisibilityTimestamp(t time.Time) {
+// SetVisibilityTime gets the visibility time stamp
+func (u *UserTimerTask) SetVisibilityTime(t time.Time) {
 	u.VisibilityTimestamp = t
 }
 
@@ -1701,12 +1720,12 @@ func (r *ActivityRetryTimerTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime gets the visibility time stamp
-func (r *ActivityRetryTimerTask) GetVisibilityTimestamp() time.Time {
+func (r *ActivityRetryTimerTask) GetVisibilityTime() time.Time {
 	return r.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp gets the visibility time stamp
-func (r *ActivityRetryTimerTask) SetVisibilityTimestamp(t time.Time) {
+// SetVisibilityTime gets the visibility time stamp
+func (r *ActivityRetryTimerTask) SetVisibilityTime(t time.Time) {
 	r.VisibilityTimestamp = t
 }
 
@@ -1736,12 +1755,12 @@ func (r *WorkflowBackoffTimerTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime gets the visibility time stamp
-func (r *WorkflowBackoffTimerTask) GetVisibilityTimestamp() time.Time {
+func (r *WorkflowBackoffTimerTask) GetVisibilityTime() time.Time {
 	return r.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp gets the visibility time stamp
-func (r *WorkflowBackoffTimerTask) SetVisibilityTimestamp(t time.Time) {
+// SetVisibilityTime gets the visibility time stamp
+func (r *WorkflowBackoffTimerTask) SetVisibilityTime(t time.Time) {
 	r.VisibilityTimestamp = t
 }
 
@@ -1771,12 +1790,12 @@ func (u *WorkflowTimeoutTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime gets the visibility time stamp
-func (u *WorkflowTimeoutTask) GetVisibilityTimestamp() time.Time {
+func (u *WorkflowTimeoutTask) GetVisibilityTime() time.Time {
 	return u.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp gets the visibility time stamp
-func (u *WorkflowTimeoutTask) SetVisibilityTimestamp(t time.Time) {
+// SetVisibilityTime gets the visibility time stamp
+func (u *WorkflowTimeoutTask) SetVisibilityTime(t time.Time) {
 	u.VisibilityTimestamp = t
 }
 
@@ -1806,12 +1825,12 @@ func (u *CancelExecutionTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (u *CancelExecutionTask) GetVisibilityTimestamp() time.Time {
+func (u *CancelExecutionTask) GetVisibilityTime() time.Time {
 	return u.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (u *CancelExecutionTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (u *CancelExecutionTask) SetVisibilityTime(timestamp time.Time) {
 	u.VisibilityTimestamp = timestamp
 }
 
@@ -1841,12 +1860,12 @@ func (u *SignalExecutionTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (u *SignalExecutionTask) GetVisibilityTimestamp() time.Time {
+func (u *SignalExecutionTask) GetVisibilityTime() time.Time {
 	return u.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (u *SignalExecutionTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (u *SignalExecutionTask) SetVisibilityTime(timestamp time.Time) {
 	u.VisibilityTimestamp = timestamp
 }
 
@@ -1876,12 +1895,12 @@ func (u *StartChildExecutionTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (u *StartChildExecutionTask) GetVisibilityTimestamp() time.Time {
+func (u *StartChildExecutionTask) GetVisibilityTime() time.Time {
 	return u.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (u *StartChildExecutionTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (u *StartChildExecutionTask) SetVisibilityTime(timestamp time.Time) {
 	u.VisibilityTimestamp = timestamp
 }
 
@@ -1911,12 +1930,12 @@ func (a *HistoryReplicationTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (a *HistoryReplicationTask) GetVisibilityTimestamp() time.Time {
+func (a *HistoryReplicationTask) GetVisibilityTime() time.Time {
 	return a.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (a *HistoryReplicationTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (a *HistoryReplicationTask) SetVisibilityTime(timestamp time.Time) {
 	a.VisibilityTimestamp = timestamp
 }
 
@@ -1946,12 +1965,12 @@ func (t *StartExecutionVisibilityTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (t *StartExecutionVisibilityTask) GetVisibilityTimestamp() time.Time {
+func (t *StartExecutionVisibilityTask) GetVisibilityTime() time.Time {
 	return t.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (t *StartExecutionVisibilityTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (t *StartExecutionVisibilityTask) SetVisibilityTime(timestamp time.Time) {
 	t.VisibilityTimestamp = timestamp
 }
 
@@ -1981,12 +2000,12 @@ func (t *UpsertExecutionVisibilityTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (t *UpsertExecutionVisibilityTask) GetVisibilityTimestamp() time.Time {
+func (t *UpsertExecutionVisibilityTask) GetVisibilityTime() time.Time {
 	return t.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (t *UpsertExecutionVisibilityTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (t *UpsertExecutionVisibilityTask) SetVisibilityTime(timestamp time.Time) {
 	t.VisibilityTimestamp = timestamp
 }
 
@@ -2016,12 +2035,12 @@ func (t *CloseExecutionVisibilityTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (t *CloseExecutionVisibilityTask) GetVisibilityTimestamp() time.Time {
+func (t *CloseExecutionVisibilityTask) GetVisibilityTime() time.Time {
 	return t.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (t *CloseExecutionVisibilityTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (t *CloseExecutionVisibilityTask) SetVisibilityTime(timestamp time.Time) {
 	t.VisibilityTimestamp = timestamp
 }
 
@@ -2051,12 +2070,12 @@ func (t *DeleteExecutionVisibilityTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (t *DeleteExecutionVisibilityTask) GetVisibilityTimestamp() time.Time {
+func (t *DeleteExecutionVisibilityTask) GetVisibilityTime() time.Time {
 	return t.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (t *DeleteExecutionVisibilityTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (t *DeleteExecutionVisibilityTask) SetVisibilityTime(timestamp time.Time) {
 	t.VisibilityTimestamp = timestamp
 }
 
@@ -2086,20 +2105,15 @@ func (a *SyncActivityTask) SetTaskID(id int64) {
 }
 
 // GetVisibilityTime get the visibility timestamp
-func (a *SyncActivityTask) GetVisibilityTimestamp() time.Time {
+func (a *SyncActivityTask) GetVisibilityTime() time.Time {
 	return a.VisibilityTimestamp
 }
 
-// SetVisibilityTimestamp set the visibility timestamp
-func (a *SyncActivityTask) SetVisibilityTimestamp(timestamp time.Time) {
+// SetVisibilityTime set the visibility timestamp
+func (a *SyncActivityTask) SetVisibilityTime(timestamp time.Time) {
 	a.VisibilityTimestamp = timestamp
 }
 
-// DBTimestampToUnixNano converts CQL timestamp to UnixNano
-func DBTimestampToUnixNano(milliseconds int64) int64 {
-	return (time.Duration(milliseconds) * time.Millisecond).Nanoseconds()
-}
-
 // UnixMilliseconds returns t as a Unix time, the number of milliseconds elapsed since January 1, 1970 UTC.
 // It should be used for all CQL timestamp.
 func UnixMilliseconds(t time.Time) int64 {
@@ -2168,6 +2182,7 @@ func SplitHistoryGarbageCleanupInfo(info string) (namespaceID, workflowID, runID
 
 // NewGetReplicationTasksFromDLQRequest creates a new GetReplicationTasksFromDLQRequest
 func NewGetReplicationTasksFromDLQRequest(
+	shardID int32,
 	sourceClusterName string,
 	readLevel int64,
 	maxReadLevel int64,
@@ -2175,6 +2190,7 @@ func NewGetReplicationTasksFromDLQRequest(
 	nextPageToken []byte,
 ) *GetReplicationTasksFromDLQRequest {
 	return &GetReplicationTasksFromDLQRequest{
+		ShardID:           shardID,
 		SourceClusterName: sourceClusterName,
 		GetReplicationTasksRequest: GetReplicationTasksRequest{
 			MinTaskID:     readLevel,
