@@ -44,8 +44,6 @@ import (
 	"go.temporal.io/server/common/persistence/visibility/elasticsearch/query"
 
 	"go.temporal.io/server/common/config"
-	"go.temporal.io/server/common/log"
-	"go.temporal.io/server/common/log/tag"
 	"go.temporal.io/server/common/metrics"
 	"go.temporal.io/server/common/persistence"
 	"go.temporal.io/server/common/searchattribute"
@@ -56,6 +54,7 @@ const (
 
 	delimiter                    = "~"
 	pointInTimeKeepAliveInterval = "1m"
+	scrollKeepAliveInterval      = "1m"
 	defaultPageSize              = 1000
 )
 
@@ -64,20 +63,19 @@ type (
 		esClient                 esclient.Client
 		index                    string
 		searchAttributesProvider searchattribute.Provider
-		logger                   log.Logger
+		searchAttributesMapper   searchattribute.Mapper
 		config                   *config.VisibilityConfig
 		metricsClient            metrics.Client
 		processor                Processor
-		queryConverter           *query.Converter
 	}
 
 	visibilityPageToken struct {
 		SearchAfter []interface{}
 
 		// For ScanWorkflowExecutions API.
-		// Deprecated. Remove after ES v6 support removal.
+		// For ES<7.10.0 and "oss" flavor.
 		ScrollID string
-		// Not supported in ES v6.
+		// For ES>=7.10.0 and "default" flavor.
 		PointInTimeID string
 	}
 )
@@ -85,7 +83,6 @@ type (
 var _ visibility.VisibilityStore = (*visibilityStore)(nil)
 
 var (
-	ErrInvalidDuration         = errors.New("invalid duration format")
 	errUnexpectedJSONFieldType = errors.New("unexpected JSON field type")
 )
 
@@ -94,9 +91,9 @@ func NewVisibilityStore(
 	esClient esclient.Client,
 	index string,
 	searchAttributesProvider searchattribute.Provider,
+	searchAttributesMapper searchattribute.Mapper,
 	processor Processor,
 	cfg *config.VisibilityConfig,
-	logger log.Logger,
 	metricsClient metrics.Client,
 ) *visibilityStore {
 
@@ -104,14 +101,10 @@ func NewVisibilityStore(
 		esClient:                 esClient,
 		index:                    index,
 		searchAttributesProvider: searchAttributesProvider,
+		searchAttributesMapper:   searchAttributesMapper,
 		processor:                processor,
-		logger:                   log.With(logger, tag.ComponentESVisibilityManager),
 		config:                   cfg,
 		metricsClient:            metricsClient,
-		queryConverter: query.NewConverter(
-			newNameInterceptor(index, searchAttributesProvider),
-			newValuesInterceptor(),
-		),
 	}
 }
 
@@ -128,14 +121,20 @@ func (s *visibilityStore) GetName() string {
 
 func (s *visibilityStore) RecordWorkflowExecutionStarted(request *visibility.InternalRecordWorkflowExecutionStartedRequest) error {
 	visibilityTaskKey := getVisibilityTaskKey(request.ShardID, request.TaskID)
-	doc := s.generateESDoc(request.InternalVisibilityRequestBase, visibilityTaskKey)
+	doc, err := s.generateESDoc(request.InternalVisibilityRequestBase, visibilityTaskKey)
+	if err != nil {
+		return err
+	}
 
 	return s.addBulkIndexRequestAndWait(request.InternalVisibilityRequestBase, doc, visibilityTaskKey)
 }
 
 func (s *visibilityStore) RecordWorkflowExecutionClosed(request *visibility.InternalRecordWorkflowExecutionClosedRequest) error {
 	visibilityTaskKey := getVisibilityTaskKey(request.ShardID, request.TaskID)
-	doc := s.generateESDoc(request.InternalVisibilityRequestBase, visibilityTaskKey)
+	doc, err := s.generateESDoc(request.InternalVisibilityRequestBase, visibilityTaskKey)
+	if err != nil {
+		return err
+	}
 
 	doc[searchattribute.CloseTime] = request.CloseTime
 	doc[searchattribute.ExecutionDuration] = request.CloseTime.Sub(request.ExecutionTime).Nanoseconds()
@@ -147,7 +146,10 @@ func (s *visibilityStore) RecordWorkflowExecutionClosed(request *visibility.Inte
 
 func (s *visibilityStore) UpsertWorkflowExecution(request *visibility.InternalUpsertWorkflowExecutionRequest) error {
 	visibilityTaskKey := getVisibilityTaskKey(request.ShardID, request.TaskID)
-	doc := s.generateESDoc(request.InternalVisibilityRequestBase, visibilityTaskKey)
+	doc, err := s.generateESDoc(request.InternalVisibilityRequestBase, visibilityTaskKey)
+	if err != nil {
+		return err
+	}
 
 	return s.addBulkIndexRequestAndWait(request.InternalVisibilityRequestBase, doc, visibilityTaskKey)
 }
@@ -238,7 +240,7 @@ func (s *visibilityStore) ListOpenWorkflowExecutions(request *visibility.ListWor
 		return !rec.StartTime.Before(request.EarliestStartTime) && !rec.StartTime.After(request.LatestStartTime)
 	}
 
-	return s.getListWorkflowExecutionsResponse(searchResult, request.PageSize, isRecordValid)
+	return s.getListWorkflowExecutionsResponse(searchResult, request.Namespace, request.PageSize, isRecordValid)
 }
 
 func (s *visibilityStore) ListClosedWorkflowExecutions(request *visibility.ListWorkflowExecutionsRequest) (*visibility.InternalListWorkflowExecutionsResponse, error) {
@@ -261,7 +263,7 @@ func (s *visibilityStore) ListClosedWorkflowExecutions(request *visibility.ListW
 		return !rec.CloseTime.Before(request.EarliestStartTime) && !rec.CloseTime.After(request.LatestStartTime)
 	}
 
-	return s.getListWorkflowExecutionsResponse(searchResult, request.PageSize, isRecordValid)
+	return s.getListWorkflowExecutionsResponse(searchResult, request.Namespace, request.PageSize, isRecordValid)
 }
 
 func (s *visibilityStore) ListOpenWorkflowExecutionsByType(request *visibility.ListWorkflowExecutionsByTypeRequest) (*visibility.InternalListWorkflowExecutionsResponse, error) {
@@ -286,7 +288,7 @@ func (s *visibilityStore) ListOpenWorkflowExecutionsByType(request *visibility.L
 		return !rec.StartTime.Before(request.EarliestStartTime) && !rec.StartTime.After(request.LatestStartTime)
 	}
 
-	return s.getListWorkflowExecutionsResponse(searchResult, request.PageSize, isRecordValid)
+	return s.getListWorkflowExecutionsResponse(searchResult, request.Namespace, request.PageSize, isRecordValid)
 }
 
 func (s *visibilityStore) ListClosedWorkflowExecutionsByType(request *visibility.ListWorkflowExecutionsByTypeRequest) (*visibility.InternalListWorkflowExecutionsResponse, error) {
@@ -310,7 +312,7 @@ func (s *visibilityStore) ListClosedWorkflowExecutionsByType(request *visibility
 		return !rec.CloseTime.Before(request.EarliestStartTime) && !rec.CloseTime.After(request.LatestStartTime)
 	}
 
-	return s.getListWorkflowExecutionsResponse(searchResult, request.PageSize, isRecordValid)
+	return s.getListWorkflowExecutionsResponse(searchResult, request.Namespace, request.PageSize, isRecordValid)
 }
 
 func (s *visibilityStore) ListOpenWorkflowExecutionsByWorkflowID(request *visibility.ListWorkflowExecutionsByWorkflowIDRequest) (*visibility.InternalListWorkflowExecutionsResponse, error) {
@@ -335,7 +337,7 @@ func (s *visibilityStore) ListOpenWorkflowExecutionsByWorkflowID(request *visibi
 		return !rec.StartTime.Before(request.EarliestStartTime) && !rec.StartTime.After(request.LatestStartTime)
 	}
 
-	return s.getListWorkflowExecutionsResponse(searchResult, request.PageSize, isRecordValid)
+	return s.getListWorkflowExecutionsResponse(searchResult, request.Namespace, request.PageSize, isRecordValid)
 }
 
 func (s *visibilityStore) ListClosedWorkflowExecutionsByWorkflowID(request *visibility.ListWorkflowExecutionsByWorkflowIDRequest) (*visibility.InternalListWorkflowExecutionsResponse, error) {
@@ -359,7 +361,7 @@ func (s *visibilityStore) ListClosedWorkflowExecutionsByWorkflowID(request *visi
 		return !rec.CloseTime.Before(request.EarliestStartTime) && !rec.CloseTime.After(request.LatestStartTime)
 	}
 
-	return s.getListWorkflowExecutionsResponse(searchResult, request.PageSize, isRecordValid)
+	return s.getListWorkflowExecutionsResponse(searchResult, request.Namespace, request.PageSize, isRecordValid)
 }
 
 func (s *visibilityStore) ListClosedWorkflowExecutionsByStatus(request *visibility.ListClosedWorkflowExecutionsByStatusRequest) (*visibility.InternalListWorkflowExecutionsResponse, error) {
@@ -382,110 +384,133 @@ func (s *visibilityStore) ListClosedWorkflowExecutionsByStatus(request *visibili
 		return !rec.CloseTime.Before(request.EarliestStartTime) && !rec.CloseTime.After(request.LatestStartTime)
 	}
 
-	return s.getListWorkflowExecutionsResponse(searchResult, request.PageSize, isRecordValid)
+	return s.getListWorkflowExecutionsResponse(searchResult, request.Namespace, request.PageSize, isRecordValid)
 }
 
 func (s *visibilityStore) ListWorkflowExecutions(request *visibility.ListWorkflowExecutionsRequestV2) (*visibility.InternalListWorkflowExecutionsResponse, error) {
-
 	p, err := s.buildSearchParametersV2(request)
 	if err != nil {
 		return nil, err
 	}
 
+	token, err := s.deserializePageToken(request.NextPageToken)
+	if err != nil {
+		return nil, err
+	}
+
+	if token != nil && len(token.SearchAfter) > 0 {
+		p.SearchAfter = token.SearchAfter
+	}
+
 	ctx := context.Background()
 	searchResult, err := s.esClient.Search(ctx, p)
 	if err != nil {
 		return nil, serviceerror.NewInternal(fmt.Sprintf("ListWorkflowExecutions failed. Error: %s", detailedErrorMessage(err)))
 	}
 
-	return s.getListWorkflowExecutionsResponse(searchResult, request.PageSize, nil)
+	return s.getListWorkflowExecutionsResponse(searchResult, request.Namespace, request.PageSize, nil)
 }
 
 func (s *visibilityStore) ScanWorkflowExecutions(request *visibility.ListWorkflowExecutionsRequestV2) (*visibility.InternalListWorkflowExecutionsResponse, error) {
-
 	ctx := context.Background()
-	switch esClient := s.esClient.(type) {
-	case client.ClientV7:
-		// Elasticsearch V7 uses "point in time" (PIT) instead of scroll to scan over all workflows without skipping them.
-		// https://www.elastic.co/guide/en/elasticsearch/reference/7.13/point-in-time-api.html
 
+	if esClientV7, isV7 := s.esClient.(client.ClientV7); isV7 {
+		// Elasticsearch 7.10+ can use "point in time" (PIT) instead of scroll to scan over all workflows without skipping or duplicating them.
+		// https://www.elastic.co/guide/en/elasticsearch/reference/7.10/point-in-time-api.html
+		if esClientV7.IsPointInTimeSupported(ctx) {
+			return s.scanWorkflowExecutionsWithPit(ctx, request, esClientV7)
+		}
+	}
+
+	return s.scanWorkflowExecutionsWithScroll(ctx, request)
+}
+
+func (s *visibilityStore) scanWorkflowExecutionsWithPit(ctx context.Context, request *visibility.ListWorkflowExecutionsRequestV2, esClient client.ClientV7) (*visibility.InternalListWorkflowExecutionsResponse, error) {
+	p, err := s.buildSearchParametersV2(request)
+	if err != nil {
+		return nil, err
+	}
+
+	// First call doesn't have token with PointInTimeID.
+	if len(request.NextPageToken) == 0 {
+		pitID, err := esClient.OpenPointInTime(ctx, s.index, pointInTimeKeepAliveInterval)
+		if err != nil {
+			return nil, serviceerror.NewInternal(fmt.Sprintf("Unable to create point in time: %s", detailedErrorMessage(err)))
+		}
+		p.PointInTime = elastic.NewPointInTime(pitID, pointInTimeKeepAliveInterval)
+	} else {
+		token, err := s.deserializePageToken(request.NextPageToken)
+		if err != nil {
+			return nil, err
+		}
+		if token.PointInTimeID == "" {
+			return nil, serviceerror.NewInvalidArgument("pointInTimeId must present in pagination token")
+		}
+		p.SearchAfter = token.SearchAfter
+		p.PointInTime = elastic.NewPointInTime(token.PointInTimeID, pointInTimeKeepAliveInterval)
+	}
+
+	searchResult, err := esClient.Search(ctx, p)
+	if err != nil {
+		return nil, serviceerror.NewInternal(fmt.Sprintf("ScanWorkflowExecutions failed. Error: %s", detailedErrorMessage(err)))
+	}
+
+	// Empty hits list indicate that this is a last page.
+	if searchResult.Hits != nil && len(searchResult.Hits.Hits) < request.PageSize {
+		_, err = esClient.ClosePointInTime(ctx, searchResult.PitId)
+		if err != nil {
+			return nil, serviceerror.NewInternal(fmt.Sprintf("Unable to close point in time: %s", detailedErrorMessage(err)))
+		}
+	}
+
+	return s.getListWorkflowExecutionsResponse(searchResult, request.Namespace, request.PageSize, nil)
+}
+
+func (s *visibilityStore) scanWorkflowExecutionsWithScroll(ctx context.Context, request *visibility.ListWorkflowExecutionsRequestV2) (*visibility.InternalListWorkflowExecutionsResponse, error) {
+	var (
+		searchResult *elastic.SearchResult
+		scrollErr    error
+	)
+
+	// First call doesn't have token with ScrollID.
+	if len(request.NextPageToken) == 0 {
+		// First page.
 		p, err := s.buildSearchParametersV2(request)
 		if err != nil {
 			return nil, err
 		}
-
-		// First call doesn't have token with PointInTimeID.
-		if p.PointInTime == nil {
-			pointInTimeID, err := esClient.OpenPointInTime(ctx, s.index, pointInTimeKeepAliveInterval)
-			if err != nil {
-				return nil, serviceerror.NewInternal(fmt.Sprintf("Unable to create point in time: %s", detailedErrorMessage(err)))
-			}
-			p.PointInTime = elastic.NewPointInTime(pointInTimeID, pointInTimeKeepAliveInterval)
-		}
-
-		searchResult, err := esClient.Search(ctx, p)
+		searchResult, scrollErr = s.esClient.OpenScroll(ctx, p, scrollKeepAliveInterval)
+	} else {
+		token, err := s.deserializePageToken(request.NextPageToken)
 		if err != nil {
-			return nil, serviceerror.NewInternal(fmt.Sprintf("ScanWorkflowExecutions failed. Error: %s", detailedErrorMessage(err)))
+			return nil, err
 		}
-
-		if len(searchResult.Hits.Hits) < request.PageSize {
-			// It is the last page, close PIT.
-			_, err = esClient.ClosePointInTime(ctx, searchResult.PitId)
-			if err != nil {
-				return nil, serviceerror.NewInternal(fmt.Sprintf("Unable to close point in time: %s", detailedErrorMessage(err)))
-			}
+		if token.ScrollID == "" {
+			return nil, serviceerror.NewInvalidArgument("scrollId must present in pagination token")
 		}
-		return s.getListWorkflowExecutionsResponse(searchResult, request.PageSize, nil)
-	case client.ClientV6:
-		var (
-			searchResult  *elastic.SearchResult
-			scrollService esclient.ScrollService
-			scrollErr     error
-		)
-
-		// First call doesn't have token with ScrollID.
-		if len(request.NextPageToken) == 0 {
-			// First page.
-			p, err := s.buildSearchParametersV2(request)
-			if err != nil {
-				return nil, err
-			}
-			searchResult, scrollService, scrollErr = esClient.ScrollFirstPage(ctx, p)
-		} else {
-			token, err := s.deserializePageToken(request.NextPageToken)
-			if err != nil {
-				return nil, err
-			}
-			if token.ScrollID == "" {
-				return nil, serviceerror.NewInvalidArgument("scrollId must present in pagination token")
-			}
-			searchResult, scrollService, scrollErr = esClient.Scroll(ctx, token.ScrollID)
-		}
-
-		isLastPage := false
-		if scrollErr == io.EOF { // no more result
-			isLastPage = true
-			_ = scrollService.Clear(context.Background())
-		} else if scrollErr != nil {
-			return nil, serviceerror.NewInternal(fmt.Sprintf("ScanWorkflowExecutions failed. Error: %s", detailedErrorMessage(scrollErr)))
-		}
-		return s.getScrollWorkflowExecutionsResponse(searchResult.Hits, request.PageSize, searchResult.ScrollId, isLastPage)
-	default:
-		panic("esClient has unsupported type")
+		searchResult, scrollErr = s.esClient.Scroll(ctx, token.ScrollID, scrollKeepAliveInterval)
 	}
+
+	if scrollErr != nil && scrollErr != io.EOF {
+		return nil, serviceerror.NewInternal(fmt.Sprintf("ScanWorkflowExecutions failed. Error: %s", detailedErrorMessage(scrollErr)))
+	}
+
+	// Both io.IOF and empty hits list indicate that this is a last page.
+	if (searchResult.Hits != nil && len(searchResult.Hits.Hits) < request.PageSize) ||
+		scrollErr == io.EOF {
+		err := s.esClient.CloseScroll(ctx, searchResult.ScrollId)
+		if err != nil {
+			return nil, serviceerror.NewInternal(fmt.Sprintf("Unable to close scroll: %s", detailedErrorMessage(err)))
+		}
+	}
+
+	return s.getListWorkflowExecutionsResponse(searchResult, request.Namespace, request.PageSize, nil)
 }
 
 func (s *visibilityStore) CountWorkflowExecutions(request *visibility.CountWorkflowExecutionsRequest) (*visibility.CountWorkflowExecutionsResponse, error) {
-
-	requestQuery, _, err := s.queryConverter.ConvertWhereOrderBy(request.Query)
+	boolQuery, _, err := s.convertQuery(request.Namespace, request.NamespaceID, request.Query)
 	if err != nil {
-		return nil, serviceerror.NewInvalidArgument(fmt.Sprintf("unable to parse query: %v", err))
-	}
-
-	// Create new bool query because request query might have only "should" (="or") queries.
-	boolQuery := elastic.NewBoolQuery().Filter(elastic.NewTermQuery(searchattribute.NamespaceID, request.NamespaceID))
-	if requestQuery != nil {
-		boolQuery.Filter(requestQuery)
+		return nil, err
 	}
 
 	ctx := context.Background()
@@ -559,22 +584,11 @@ func (s *visibilityStore) buildSearchParametersV2(
 	request *visibility.ListWorkflowExecutionsRequestV2,
 ) (*client.SearchParameters, error) {
 
-	token, err := s.deserializePageToken(request.NextPageToken)
+	boolQuery, fieldSorts, err := s.convertQuery(request.Namespace, request.NamespaceID, request.Query)
 	if err != nil {
 		return nil, err
 	}
 
-	requestQuery, fieldSorts, err := s.queryConverter.ConvertWhereOrderBy(request.Query)
-	if err != nil {
-		return nil, serviceerror.NewInvalidArgument(fmt.Sprintf("unable to parse query: %v", err))
-	}
-
-	// Create new bool query because request query might have only "should" (="or") queries.
-	boolQuery := elastic.NewBoolQuery().Filter(elastic.NewTermQuery(searchattribute.NamespaceID, request.NamespaceID))
-	if requestQuery != nil {
-		boolQuery.Filter(requestQuery)
-	}
-
 	params := &esclient.SearchParameters{
 		Index:    s.index,
 		Query:    boolQuery,
@@ -586,16 +600,34 @@ func (s *visibilityStore) buildSearchParametersV2(
 		params.PageSize = defaultPageSize
 	}
 
-	if token != nil {
-		if len(token.SearchAfter) > 0 {
-			params.SearchAfter = token.SearchAfter
-		}
-		if token.PointInTimeID != "" {
-			params.PointInTime = elastic.NewPointInTime(token.PointInTimeID, pointInTimeKeepAliveInterval)
+	return params, nil
+}
+func (s *visibilityStore) convertQuery(namespace string, namespaceID string, requestQueryStr string) (*elastic.BoolQuery, []*elastic.FieldSort, error) {
+	saTypeMap, err := s.searchAttributesProvider.GetSearchAttributes(s.index, false)
+	if err != nil {
+		return nil, nil, serviceerror.NewInternal(fmt.Sprintf("Unable to read search attribute types: %v", err))
+	}
+	queryConverter := query.NewConverter(
+		newNameInterceptor(namespace, s.index, saTypeMap, s.searchAttributesMapper),
+		newValuesInterceptor(),
+	)
+	requestQuery, fieldSorts, err := queryConverter.ConvertWhereOrderBy(requestQueryStr)
+	if err != nil {
+		// Convert query.ConverterError to serviceerror.InvalidArgument and pass through all other errors (which should be only mapper errors).
+		var converterErr *query.ConverterError
+		if errors.As(err, &converterErr) {
+			return nil, nil, serviceerror.NewInvalidArgument(fmt.Sprintf("unable to parse query: %v", converterErr))
 		}
+		return nil, nil, err
 	}
 
-	return params, nil
+	// Create new bool query because request query might have only "should" (="or") queries.
+	namespaceFilterQuery := elastic.NewBoolQuery().Filter(elastic.NewTermQuery(searchattribute.NamespaceID, namespaceID))
+	if requestQuery != nil {
+		namespaceFilterQuery.Filter(requestQuery)
+	}
+
+	return namespaceFilterQuery, fieldSorts, nil
 }
 
 func (s *visibilityStore) setDefaultFieldSort(fieldSorts []*elastic.FieldSort) []elastic.Sorter {
@@ -619,6 +651,7 @@ func (s *visibilityStore) setDefaultFieldSort(fieldSorts []*elastic.FieldSort) [
 
 func (s *visibilityStore) getScrollWorkflowExecutionsResponse(
 	searchHits *elastic.SearchHits,
+	namespace string,
 	pageSize int,
 	scrollID string,
 	isLastPage bool,
@@ -626,14 +659,16 @@ func (s *visibilityStore) getScrollWorkflowExecutionsResponse(
 
 	typeMap, err := s.searchAttributesProvider.GetSearchAttributes(s.index, false)
 	if err != nil {
-		s.logger.Error("Unable to read search attribute types.", tag.Error(err))
-		return nil, err
+		return nil, serviceerror.NewInternal(fmt.Sprintf("Unable to read search attribute types: %v", err))
 	}
 
 	response := &visibility.InternalListWorkflowExecutionsResponse{}
 	response.Executions = make([]*visibility.VisibilityWorkflowExecutionInfo, len(searchHits.Hits))
 	for i := 0; i < len(searchHits.Hits); i++ {
-		response.Executions[i] = s.parseESDoc(searchHits.Hits[i], typeMap)
+		response.Executions[i], err = s.parseESDoc(searchHits.Hits[i], typeMap, namespace)
+		if err != nil {
+			return nil, err
+		}
 	}
 
 	if len(searchHits.Hits) == pageSize && !isLastPage {
@@ -650,14 +685,18 @@ func (s *visibilityStore) getScrollWorkflowExecutionsResponse(
 
 func (s *visibilityStore) getListWorkflowExecutionsResponse(
 	searchResult *elastic.SearchResult,
+	namespace string,
 	pageSize int,
 	isRecordValid func(rec *visibility.VisibilityWorkflowExecutionInfo) bool,
 ) (*visibility.InternalListWorkflowExecutionsResponse, error) {
 
+	if searchResult.Hits == nil || len(searchResult.Hits.Hits) == 0 {
+		return &visibility.InternalListWorkflowExecutionsResponse{}, nil
+	}
+
 	typeMap, err := s.searchAttributesProvider.GetSearchAttributes(s.index, false)
 	if err != nil {
-		s.logger.Error("Unable to read search attribute types.", tag.Error(err))
-		return nil, err
+		return nil, serviceerror.NewInternal(fmt.Sprintf("Unable to read search attribute types: %v", err))
 	}
 
 	response := &visibility.InternalListWorkflowExecutionsResponse{
@@ -665,7 +704,10 @@ func (s *visibilityStore) getListWorkflowExecutionsResponse(
 	}
 	var lastHitSort []interface{}
 	for _, hit := range searchResult.Hits.Hits {
-		workflowExecutionInfo := s.parseESDoc(hit, typeMap)
+		workflowExecutionInfo, err := s.parseESDoc(hit, typeMap, namespace)
+		if err != nil {
+			return nil, err
+		}
 		// ES6 uses "date" data type not "date_nanos". It truncates dates using milliseconds and might return extra rows.
 		// For example: 2021-06-12T00:21:43.159739259Z fits 2021-06-12T00:21:43.158Z...2021-06-12T00:21:43.159Z range lte/gte query.
 		// Therefore, these records need to be filtered out on the client side to support nanos precision.
@@ -680,6 +722,7 @@ func (s *visibilityStore) getListWorkflowExecutionsResponse(
 		response.NextPageToken, err = s.serializePageToken(&visibilityPageToken{
 			SearchAfter:   lastHitSort,
 			PointInTimeID: searchResult.PitId,
+			ScrollID:      searchResult.ScrollId,
 		})
 		if err != nil {
 			return nil, err
@@ -717,7 +760,7 @@ func (s *visibilityStore) serializePageToken(token *visibilityPageToken) ([]byte
 	return data, nil
 }
 
-func (s *visibilityStore) generateESDoc(request *visibility.InternalVisibilityRequestBase, visibilityTaskKey string) map[string]interface{} {
+func (s *visibilityStore) generateESDoc(request *visibility.InternalVisibilityRequestBase, visibilityTaskKey string) (map[string]interface{}, error) {
 	doc := map[string]interface{}{
 		searchattribute.VisibilityTaskKey: visibilityTaskKey,
 		searchattribute.NamespaceID:       request.NamespaceID,
@@ -737,24 +780,26 @@ func (s *visibilityStore) generateESDoc(request *visibility.InternalVisibilityRe
 
 	typeMap, err := s.searchAttributesProvider.GetSearchAttributes(s.index, false)
 	if err != nil {
-		s.logger.Error("Unable to read search attribute types.", tag.Error(err))
+		s.metricsClient.IncCounter(metrics.ElasticsearchVisibility, metrics.ElasticsearchDocumentGenerateFailuresCount)
+		return nil, serviceerror.NewInternal(fmt.Sprintf("Unable to read search attribute types: %v", err))
 	}
 
 	searchAttributes, err := searchattribute.Decode(request.SearchAttributes, &typeMap)
 	if err != nil {
-		s.logger.Error("Unable to decode search attributes.", tag.Error(err))
+		s.metricsClient.IncCounter(metrics.ElasticsearchVisibility, metrics.ElasticsearchDocumentGenerateFailuresCount)
+		return nil, serviceerror.NewInternal(fmt.Sprintf("Unable to decode search attributes: %v", err))
 	}
 	for saName, saValue := range searchAttributes {
 		doc[saName] = saValue
 	}
 
-	return doc
+	return doc, nil
 }
 
-func (s *visibilityStore) parseESDoc(hit *elastic.SearchHit, saTypeMap searchattribute.NameTypeMap) *visibility.VisibilityWorkflowExecutionInfo {
-	logParseError := func(fieldName string, fieldValue interface{}, err error, docID string) {
-		s.logger.Error("Unable to parse Elasticsearch document field.", tag.Name(fieldName), tag.Value(fieldValue), tag.Error(err), tag.ESDocID(docID))
-		s.metricsClient.IncCounter(metrics.ElasticsearchVisibility, metrics.ElasticsearchInvalidSearchAttributeCount)
+func (s *visibilityStore) parseESDoc(hit *elastic.SearchHit, saTypeMap searchattribute.NameTypeMap, namespace string) (*visibility.VisibilityWorkflowExecutionInfo, error) {
+	logParseError := func(fieldName string, fieldValue interface{}, err error, docID string) error {
+		s.metricsClient.IncCounter(metrics.ElasticsearchVisibility, metrics.ElasticsearchDocumentParseFailuresCount)
+		return serviceerror.NewInternal(fmt.Sprintf("Unable to parse Elasticsearch document(%s) %q field value %q: %v", docID, fieldName, fieldValue, err))
 	}
 
 	var sourceMap map[string]interface{}
@@ -762,13 +807,16 @@ func (s *visibilityStore) parseESDoc(hit *elastic.SearchHit, saTypeMap searchatt
 	// Very important line. See finishParseJSONValue bellow.
 	d.UseNumber()
 	if err := d.Decode(&sourceMap); err != nil {
-		s.logger.Error("Unable to JSON unmarshal Elasticsearch SearchHit.Source.", tag.Error(err), tag.ESDocID(hit.Id))
-		return nil
+		s.metricsClient.IncCounter(metrics.ElasticsearchVisibility, metrics.ElasticsearchDocumentParseFailuresCount)
+		return nil, serviceerror.NewInternal(fmt.Sprintf("Unable to unmarshal JSON from Elasticsearch document(%s): %v", hit.Id, err))
 	}
 
-	var isValidType bool
-	var memo []byte
-	var memoEncoding string
+	var (
+		isValidType            bool
+		memo                   []byte
+		memoEncoding           string
+		customSearchAttributes map[string]interface{}
+	)
 	record := &visibility.VisibilityWorkflowExecutionInfo{}
 	for fieldName, fieldValue := range sourceMap {
 		switch fieldName {
@@ -780,16 +828,16 @@ func (s *visibilityStore) parseESDoc(hit *elastic.SearchHit, saTypeMap searchatt
 		case searchattribute.Memo:
 			var memoStr string
 			if memoStr, isValidType = fieldValue.(string); !isValidType {
-				logParseError(fieldName, fieldValue, fmt.Errorf("%w: expected string got %T", errUnexpectedJSONFieldType, fieldValue), hit.Id)
+				return nil, logParseError(fieldName, fieldValue, fmt.Errorf("%w: expected string got %T", errUnexpectedJSONFieldType, fieldValue), hit.Id)
 			}
 			var err error
 			if memo, err = base64.StdEncoding.DecodeString(memoStr); err != nil {
-				logParseError(fieldName, memoStr[:10], err, hit.Id)
+				return nil, logParseError(fieldName, memoStr[:10], err, hit.Id)
 			}
 			continue
 		case searchattribute.MemoEncoding:
 			if memoEncoding, isValidType = fieldValue.(string); !isValidType {
-				logParseError(fieldName, fieldValue, fmt.Errorf("%w: expected string got %T", errUnexpectedJSONFieldType, fieldValue), hit.Id)
+				return nil, logParseError(fieldName, fieldValue, fmt.Errorf("%w: expected string got %T", errUnexpectedJSONFieldType, fieldValue), hit.Id)
 			}
 			continue
 		}
@@ -797,16 +845,16 @@ func (s *visibilityStore) parseESDoc(hit *elastic.SearchHit, saTypeMap searchatt
 		fieldType, err := saTypeMap.GetType(fieldName)
 		if err != nil {
 			// Silently ignore ErrInvalidName because it indicates unknown field in Elasticsearch document.
-			if !errors.Is(err, searchattribute.ErrInvalidName) {
-				s.logger.Error("Unable to get type for Elasticsearch document field.", tag.Name(fieldName), tag.Error(err), tag.ESDocID(hit.Id))
+			if errors.Is(err, searchattribute.ErrInvalidName) {
+				continue
 			}
-			continue
+			s.metricsClient.IncCounter(metrics.ElasticsearchVisibility, metrics.ElasticsearchDocumentParseFailuresCount)
+			return nil, serviceerror.NewInternal(fmt.Sprintf("Unable to get type for Elasticsearch document(%s) field %q: %v", hit.Id, fieldName, err))
 		}
 
 		fieldValueParsed, err := finishParseJSONValue(fieldValue, fieldType)
 		if err != nil {
-			logParseError(fieldName, fieldValue, err, hit.Id)
-			continue
+			return nil, logParseError(fieldName, fieldValue, err, hit.Id)
 		}
 
 		switch fieldName {
@@ -831,22 +879,35 @@ func (s *visibilityStore) parseESDoc(hit *elastic.SearchHit, saTypeMap searchatt
 		case searchattribute.StateTransitionCount:
 			record.StateTransitionCount = fieldValueParsed.(int64)
 		default:
-			// All custom search attributes are handled here.
-			if record.SearchAttributes == nil {
-				record.SearchAttributes = map[string]interface{}{}
+			// All custom and predefined search attributes are handled here.
+			if customSearchAttributes == nil {
+				customSearchAttributes = map[string]interface{}{}
 			}
-			record.SearchAttributes[fieldName] = fieldValueParsed
+			customSearchAttributes[fieldName] = fieldValueParsed
+		}
+	}
+
+	if customSearchAttributes != nil {
+		var err error
+		record.SearchAttributes, err = searchattribute.Encode(customSearchAttributes, &saTypeMap)
+		if err != nil {
+			s.metricsClient.IncCounter(metrics.ElasticsearchVisibility, metrics.ElasticsearchDocumentParseFailuresCount)
+			return nil, serviceerror.NewInternal(fmt.Sprintf("Unable to encode custom search attributes of Elasticsearch document(%s): %v", hit.Id, err))
+		}
+		err = searchattribute.ApplyAliases(s.searchAttributesMapper, record.SearchAttributes, namespace)
+		if err != nil {
+			return nil, err
 		}
 	}
 
 	if memoEncoding != "" {
 		record.Memo = persistence.NewDataBlob(memo, memoEncoding)
 	} else if memo != nil {
-		s.logger.Error("Field is missing in Elasticsearch document.", tag.Name(searchattribute.MemoEncoding), tag.ESDocID(hit.Id))
-		s.metricsClient.IncCounter(metrics.ElasticsearchVisibility, metrics.ElasticsearchInvalidSearchAttributeCount)
+		s.metricsClient.IncCounter(metrics.ElasticsearchVisibility, metrics.ElasticsearchDocumentParseFailuresCount)
+		return nil, serviceerror.NewInternal(fmt.Sprintf("%q field is missing in Elasticsearch document(%s)", searchattribute.MemoEncoding, hit.Id))
 	}
 
-	return record
+	return record, nil
 }
 
 // finishParseJSONValue finishes JSON parsing after json.Decode.
