@@ -31,7 +31,6 @@ import (
 	commonpb "go.temporal.io/api/common/v1"
 
 	"go.temporal.io/server/common/dynamicconfig"
-	"go.temporal.io/server/common/log"
 	"go.temporal.io/server/common/payload"
 )
 
@@ -49,8 +48,9 @@ func (s *searchAttributesValidatorSuite) TestSearchAttributesValidate() {
 	sizeOfValueLimit := 5
 	sizeOfTotalLimit := 20
 
-	saValidator := NewValidator(log.NewNoopLogger(),
+	saValidator := NewValidator(
 		NewTestProvider(),
+		nil,
 		dynamicconfig.GetIntPropertyFilteredByNamespace(numOfKeysLimit),
 		dynamicconfig.GetIntPropertyFilteredByNamespace(sizeOfValueLimit),
 		dynamicconfig.GetIntPropertyFilteredByNamespace(sizeOfTotalLimit))
@@ -59,7 +59,7 @@ func (s *searchAttributesValidatorSuite) TestSearchAttributesValidate() {
 	var attr *commonpb.SearchAttributes
 
 	err := saValidator.Validate(attr, namespace, "")
-	s.Nil(err)
+	s.NoError(err)
 
 	intPayload, err := payload.Encode(1)
 	s.NoError(err)
@@ -70,7 +70,7 @@ func (s *searchAttributesValidatorSuite) TestSearchAttributesValidate() {
 		IndexedFields: fields,
 	}
 	err = saValidator.Validate(attr, namespace, "")
-	s.Nil(err)
+	s.NoError(err)
 
 	fields = map[string]*commonpb.Payload{
 		"CustomIntField":     intPayload,
@@ -117,13 +117,74 @@ func (s *searchAttributesValidatorSuite) TestSearchAttributesValidate() {
 	s.Equal("StartTime attribute can't be set in SearchAttributes", err.Error())
 }
 
+func (s *searchAttributesValidatorSuite) TestSearchAttributesValidate_Mapper() {
+	numOfKeysLimit := 2
+	sizeOfValueLimit := 5
+	sizeOfTotalLimit := 20
+
+	saValidator := NewValidator(
+		NewTestProvider(),
+		&TestMapper{},
+		dynamicconfig.GetIntPropertyFilteredByNamespace(numOfKeysLimit),
+		dynamicconfig.GetIntPropertyFilteredByNamespace(sizeOfValueLimit),
+		dynamicconfig.GetIntPropertyFilteredByNamespace(sizeOfTotalLimit))
+
+	namespace := "test"
+	var attr *commonpb.SearchAttributes
+
+	err := saValidator.Validate(attr, namespace, "")
+	s.Nil(err)
+
+	intPayload, err := payload.Encode(1)
+	s.NoError(err)
+	fields := map[string]*commonpb.Payload{
+		"alias_of_CustomIntField": intPayload,
+	}
+	attr = &commonpb.SearchAttributes{
+		IndexedFields: fields,
+	}
+	err = saValidator.Validate(attr, namespace, "")
+	s.NoError(err)
+
+	err = saValidator.Validate(attr, "error", "")
+	s.Error(err)
+	s.EqualError(err, "mapper error")
+
+	fields = map[string]*commonpb.Payload{
+		"CustomIntField": intPayload,
+	}
+	attr = &commonpb.SearchAttributes{
+		IndexedFields: fields,
+	}
+	err = saValidator.Validate(attr, "namespace", "")
+	s.NoError(err)
+
+	fields = map[string]*commonpb.Payload{
+		"alias_of_InvalidKey": payload.EncodeString("1"),
+	}
+	attr.IndexedFields = fields
+	err = saValidator.Validate(attr, namespace, "")
+	s.Error(err)
+	s.Equal("alias_of_InvalidKey is not a valid search attribute name", err.Error())
+
+	fields = map[string]*commonpb.Payload{
+		"alias_of_CustomStringField": payload.EncodeString("1"),
+		"alias_of_CustomBoolField":   payload.EncodeString("123"),
+	}
+	attr.IndexedFields = fields
+	err = saValidator.Validate(attr, namespace, "")
+	s.Error(err)
+	s.Equal("123 is not a valid value for search attribute alias_of_CustomBoolField of type Bool", err.Error())
+}
+
 func (s *searchAttributesValidatorSuite) TestSearchAttributesValidateSize() {
 	numOfKeysLimit := 2
 	sizeOfValueLimit := 5
 	sizeOfTotalLimit := 20
 
-	saValidator := NewValidator(log.NewNoopLogger(),
+	saValidator := NewValidator(
 		NewTestProvider(),
+		nil,
 		dynamicconfig.GetIntPropertyFilteredByNamespace(numOfKeysLimit),
 		dynamicconfig.GetIntPropertyFilteredByNamespace(sizeOfValueLimit),
 		dynamicconfig.GetIntPropertyFilteredByNamespace(sizeOfTotalLimit))
