@@ -27,6 +27,7 @@ package history
 import (
 	"context"
 	"errors"
+	"strings"
 	"testing"
 	"time"
 
@@ -42,6 +43,8 @@ import (
 	"go.temporal.io/api/serviceerror"
 	taskqueuepb "go.temporal.io/api/taskqueue/v1"
 	"go.temporal.io/api/workflowservice/v1"
+	"go.temporal.io/server/common/payload"
+	"go.temporal.io/server/common/searchattribute"
 
 	enumsspb "go.temporal.io/server/api/enums/v1"
 	"go.temporal.io/server/api/historyservice/v1"
@@ -139,20 +142,28 @@ func (s *engine2Suite) SetupTest() {
 
 	historyCache := workflow.NewCache(s.mockShard)
 	h := &historyEngineImpl{
-		currentClusterName: s.mockShard.GetClusterMetadata().GetCurrentClusterName(),
-		shard:              s.mockShard,
-		clusterMetadata:    s.mockClusterMetadata,
-		executionManager:   s.mockExecutionMgr,
-		historyCache:       historyCache,
-		logger:             s.logger,
-		throttledLogger:    s.logger,
-		metricsClient:      metrics.NewClient(tally.NoopScope, metrics.History),
-		tokenSerializer:    common.NewProtoTaskTokenSerializer(),
-		config:             s.config,
-		timeSource:         s.mockShard.GetTimeSource(),
-		eventNotifier:      events.NewNotifier(clock.NewRealTimeSource(), metrics.NewClient(tally.NoopScope, metrics.History), func(string, string) int32 { return 1 }),
-		txProcessor:        s.mockTxProcessor,
-		timerProcessor:     s.mockTimerProcessor,
+		currentClusterName:     s.mockShard.GetClusterMetadata().GetCurrentClusterName(),
+		shard:                  s.mockShard,
+		clusterMetadata:        s.mockClusterMetadata,
+		executionManager:       s.mockExecutionMgr,
+		historyCache:           historyCache,
+		logger:                 s.logger,
+		throttledLogger:        s.logger,
+		metricsClient:          metrics.NewClient(tally.NoopScope, metrics.History),
+		tokenSerializer:        common.NewProtoTaskTokenSerializer(),
+		config:                 s.config,
+		timeSource:             s.mockShard.GetTimeSource(),
+		eventNotifier:          events.NewNotifier(clock.NewRealTimeSource(), metrics.NewClient(tally.NoopScope, metrics.History), func(string, string) int32 { return 1 }),
+		txProcessor:            s.mockTxProcessor,
+		timerProcessor:         s.mockTimerProcessor,
+		searchAttributesMapper: s.mockShard.Resource.SearchAttributesMapper,
+		searchAttributesValidator: searchattribute.NewValidator(
+			searchattribute.NewTestProvider(),
+			s.mockShard.Resource.SearchAttributesMapper,
+			s.config.SearchAttributesNumberOfKeysLimit,
+			s.config.SearchAttributesSizeOfValueLimit,
+			s.config.SearchAttributesTotalSizeLimit,
+		),
 	}
 	s.mockShard.SetEngine(h)
 	h.workflowTaskHandler = newWorkflowTaskHandlerCallback(h)
@@ -882,6 +893,41 @@ func (s *engine2Suite) TestStartWorkflowExecution_BrandNew() {
 	s.NotNil(resp.RunId)
 }
 
+func (s *engine2Suite) TestStartWorkflowExecution_BrandNew_SearchAttributes() {
+	namespaceID := tests.NamespaceID
+	workflowID := "workflowID"
+	workflowType := "workflowType"
+	taskQueue := "testTaskQueue"
+	identity := "testIdentity"
+
+	s.mockExecutionMgr.EXPECT().CreateWorkflowExecution(gomock.Any()).Return(&persistence.CreateWorkflowExecutionResponse{}, nil)
+	s.mockShard.Resource.SearchAttributesMapper.EXPECT().GetFieldName(gomock.Any(), gomock.Any()).DoAndReturn(
+		func(alias string, namespace string) (string, error) {
+			return strings.TrimPrefix(alias, "AliasFor"), nil
+		}).Times(2)
+
+	requestID := uuid.New()
+	resp, err := s.historyEngine.StartWorkflowExecution(metrics.AddMetricsContext(context.Background()), &historyservice.StartWorkflowExecutionRequest{
+		Attempt:     1,
+		NamespaceId: namespaceID,
+		StartRequest: &workflowservice.StartWorkflowExecutionRequest{
+			Namespace:                namespaceID,
+			WorkflowId:               workflowID,
+			WorkflowType:             &commonpb.WorkflowType{Name: workflowType},
+			TaskQueue:                &taskqueuepb.TaskQueue{Name: taskQueue},
+			WorkflowExecutionTimeout: timestamp.DurationPtr(20 * time.Second),
+			WorkflowRunTimeout:       timestamp.DurationPtr(1 * time.Second),
+			WorkflowTaskTimeout:      timestamp.DurationPtr(2 * time.Second),
+			Identity:                 identity,
+			RequestId:                requestID,
+			SearchAttributes: &commonpb.SearchAttributes{IndexedFields: map[string]*commonpb.Payload{
+				"AliasForCustomKeywordField": payload.EncodeString("test"),
+			}}},
+	})
+	s.Nil(err)
+	s.NotNil(resp.RunId)
+}
+
 func (s *engine2Suite) TestStartWorkflowExecution_StillRunning_Dedup() {
 	namespaceID := tests.NamespaceID
 	workflowID := "workflowID"
