@@ -371,6 +371,7 @@ func (p *ReplicationTaskProcessorImpl) convertTaskToDLQTask(
 	case enumsspb.REPLICATION_TASK_TYPE_SYNC_ACTIVITY_TASK:
 		taskAttributes := replicationTask.GetSyncActivityTaskAttributes()
 		return &persistence.PutReplicationTaskToDLQRequest{
+			ShardID:           p.shard.GetShardID(),
 			SourceClusterName: p.sourceCluster,
 			TaskInfo: &persistencespb.ReplicationTaskInfo{
 				NamespaceId: taskAttributes.GetNamespaceId(),
@@ -386,8 +387,7 @@ func (p *ReplicationTaskProcessorImpl) convertTaskToDLQTask(
 	case enumsspb.REPLICATION_TASK_TYPE_HISTORY_V2_TASK:
 		taskAttributes := replicationTask.GetHistoryTaskV2Attributes()
 
-		eventsDataBlob := persistence.NewDataBlobFromProto(taskAttributes.GetEvents())
-		events, err := p.historySerializer.DeserializeEvents(eventsDataBlob)
+		events, err := p.historySerializer.DeserializeEvents(taskAttributes.GetEvents())
 		if err != nil {
 			return nil, err
 		}
@@ -402,6 +402,7 @@ func (p *ReplicationTaskProcessorImpl) convertTaskToDLQTask(
 		nextEventID := lastEvent.GetEventId() + 1
 
 		return &persistence.PutReplicationTaskToDLQRequest{
+			ShardID:           p.shard.GetShardID(),
 			SourceClusterName: p.sourceCluster,
 			TaskInfo: &persistencespb.ReplicationTaskInfo{
 				NamespaceId:  taskAttributes.GetNamespaceId(),
