@@ -31,6 +31,7 @@ import (
 	"github.com/golang/mock/gomock"
 	"github.com/stretchr/testify/require"
 	"github.com/stretchr/testify/suite"
+	"go.temporal.io/server/common/persistence/visibility"
 
 	"go.temporal.io/server/common/searchattribute"
 	"go.temporal.io/server/service/history/workflow"
@@ -58,8 +59,7 @@ type (
 		mockMutableState             *workflow.MockMutableState
 
 		mockExecutionManager         *persistence.MockExecutionManager
-		mockVisibilityManager        *persistence.MockVisibilityManager
-		mockHistoryMgr               *persistence.MockHistoryManager
+		mockVisibilityManager        *visibility.MockVisibilityManager
 		mockArchivalClient           *archiver.MockClient
 		mockNamespaceCache           *cache.MockNamespaceCache
 		mockClusterMetadata          *cluster.MockMetadata
@@ -105,7 +105,6 @@ func (s *timerQueueTaskExecutorBaseSuite) SetupTest() {
 
 	s.mockExecutionManager = s.mockShard.Resource.ExecutionMgr
 	s.mockVisibilityManager = s.mockShard.Resource.VisibilityMgr
-	s.mockHistoryMgr = s.mockShard.Resource.HistoryMgr
 	s.mockArchivalClient = archiver.NewMockClient(s.controller)
 	s.mockNamespaceCache = s.mockShard.Resource.NamespaceCache
 	s.mockClusterMetadata = s.mockShard.Resource.ClusterMetadata
@@ -118,7 +117,6 @@ func (s *timerQueueTaskExecutorBaseSuite) SetupTest() {
 		logger:          logger,
 		metricsClient:   s.mockShard.GetMetricsClient(),
 		visibilityMgr:   s.mockVisibilityManager,
-		historyV2Mgr:    s.mockHistoryMgr,
 		archivalClient:  s.mockArchivalClient,
 		clusterMetadata: s.mockClusterMetadata,
 	}
@@ -155,7 +153,7 @@ func (s *timerQueueTaskExecutorBaseSuite) TestDeleteWorkflow_NoErr() {
 
 	s.mockExecutionManager.EXPECT().DeleteCurrentWorkflowExecution(gomock.Any()).Return(nil)
 	s.mockExecutionManager.EXPECT().DeleteWorkflowExecution(gomock.Any()).Return(nil)
-	s.mockHistoryMgr.EXPECT().DeleteHistoryBranch(gomock.Any()).Return(nil)
+	s.mockExecutionManager.EXPECT().DeleteHistoryBranch(gomock.Any()).Return(nil)
 	s.mockMutableState.EXPECT().GetCurrentBranchToken().Return([]byte{1, 2, 3}, nil)
 
 	err := s.timerQueueTaskExecutorBase.deleteWorkflow(task, s.mockWorkflowExecutionContext, s.mockMutableState)
