@@ -35,6 +35,7 @@ import (
 	failurepb "go.temporal.io/api/failure/v1"
 	historypb "go.temporal.io/api/history/v1"
 	"go.temporal.io/api/serviceerror"
+	"go.temporal.io/server/common/searchattribute"
 
 	"go.temporal.io/server/common"
 	"go.temporal.io/server/common/backoff"
@@ -66,8 +67,9 @@ type (
 		initiatedChildExecutionsInBatch map[string]struct{} // Set of initiated child executions in the workflow task
 
 		// validation
-		attrValidator    *commandAttrValidator
-		sizeLimitChecker *workflowSizeChecker
+		attrValidator          *commandAttrValidator
+		sizeLimitChecker       *workflowSizeChecker
+		searchAttributesMapper searchattribute.Mapper
 
 		logger         log.Logger
 		namespaceCache cache.NamespaceCache
@@ -91,6 +93,7 @@ func newWorkflowTaskHandler(
 	namespaceCache cache.NamespaceCache,
 	metricsClient metrics.Client,
 	config *configs.Config,
+	searchAttributesMapper searchattribute.Mapper,
 ) *workflowTaskHandlerImpl {
 
 	return &workflowTaskHandlerImpl{
@@ -107,8 +110,9 @@ func newWorkflowTaskHandler(
 		initiatedChildExecutionsInBatch: make(map[string]struct{}),
 
 		// validation
-		attrValidator:    attrValidator,
-		sizeLimitChecker: sizeLimitChecker,
+		attrValidator:          attrValidator,
+		sizeLimitChecker:       sizeLimitChecker,
+		searchAttributesMapper: searchAttributesMapper,
 
 		logger:         logger,
 		namespaceCache: namespaceCache,
@@ -683,6 +687,11 @@ func (handler *workflowTaskHandlerImpl) handleCommandContinueAsNewWorkflow(
 		return err
 	}
 
+	if err := searchattribute.SubstituteAliases(handler.searchAttributesMapper, attr.GetSearchAttributes(), namespace); err != nil {
+		handler.stopProcessing = true
+		return err
+	}
+
 	// If the workflow task has more than one completion event than just pick the first one
 	if !handler.mutableState.IsWorkflowExecutionRunning() {
 		handler.metricsClient.IncCounter(
@@ -794,6 +803,11 @@ func (handler *workflowTaskHandlerImpl) handleCommandStartChildWorkflow(
 		return err
 	}
 
+	if err := searchattribute.SubstituteAliases(handler.searchAttributesMapper, attr.GetSearchAttributes(), targetNamespace); err != nil {
+		handler.stopProcessing = true
+		return err
+	}
+
 	enabled := handler.config.EnableParentClosePolicy(parentNamespace)
 	if enabled {
 		enums.SetDefaultParentClosePolicy(&attr.ParentClosePolicy)
@@ -917,6 +931,11 @@ func (handler *workflowTaskHandlerImpl) handleCommandUpsertWorkflowSearchAttribu
 		return err
 	}
 
+	if err := searchattribute.SubstituteAliases(handler.searchAttributesMapper, attr.GetSearchAttributes(), namespace); err != nil {
+		handler.stopProcessing = true
+		return err
+	}
+
 	_, err = handler.mutableState.AddUpsertWorkflowSearchAttributesEvent(
 		handler.workflowTaskCompletedID, attr,
 	)
